@@ -303,7 +303,7 @@ class GaussianMixtureBase(metaclass=ABCMeta):
         pass
 
     @abstractmethod
-    def plot_pdf_surface(self, data_frame_object):
+    def get_pdf_fig(self, data_frame_object):
         """Plot the pdf of the Gaussian mixture on a surface.
 
         The returned matplotlib.plyplot figure can be shown and saved
@@ -328,7 +328,7 @@ class GaussianMixtureBase(metaclass=ABCMeta):
         pass
 
     @abstractmethod
-    def show_results(self, data_frame_object):
+    def get_results_fig(self, data_frame_object):
         """Return the clustering results.
 
         The returned matplotlib.plyplot figure may be shown
@@ -386,7 +386,7 @@ class GaussianMixtureBase(metaclass=ABCMeta):
             raise NotImplementedError("Must run a method to cluster the "
                                       "data before visualization.")
 
-        fig, save_string = self.show_results(data_frame_object=data_frame_object)
+        fig, save_string = self.get_results_fig(data_frame_object=data_frame_object)
         
         canvas = FigureCanvas(fig)  # Initialize the canvas, which is the renderer that works with RGB values
         canvas.draw()  # Draw the canvas and cache the renderer
@@ -413,50 +413,54 @@ class GaussianMixtureBase(metaclass=ABCMeta):
                       "multiple spots you want to do this with, close out the figure after addressing \n"
                       "the first spot and look for the next prompt.")
                 root.mainloop()  # Run GUI
+                
+                if len(color_list) > 1:
+                    colors = ['blue', 'salmon', 'green', 'cadetblue', 'yellow',
+                              'cyan', 'indianred', 'chartreuse', 'seagreen',
+                              'darkorange', 'purple', 'aliceblue', 'olivedrab',
+                              'deeppink', 'tan', 'rosybrown', 'khaki',
+                              'aquamarine', 'cornflowerblue', 'saddlebrown',
+                              'lightgray']
 
-                colors = ['blue', 'salmon', 'green', 'cadetblue', 'yellow',
-                          'cyan', 'indianred', 'chartreuse', 'seagreen',
-                          'darkorange', 'purple', 'aliceblue', 'olivedrab',
-                          'deeppink', 'tan', 'rosybrown', 'khaki',
-                          'aquamarine', 'cornflowerblue', 'saddlebrown',
-                          'lightgray']
+                    # Find indexes of colors
+                    true_index_list = []  # Corresponds to the indices of the clusters in centers_array
+                    cluster_index_list = []  # Corresponds to the indices of the clusters relative to labels_ and colors
+                    for color in color_list:
+                        true_index_list.append(self.colors_.index(color))
+                        cluster_index_list.append(colors.index(color))
+                    ips_list = list(self.ips_)
+                    true_index_keep = ips_list.index(max(self.ips_[true_index_list]))
+                    cluster_index_keep = cluster_index_list[true_index_list.index(true_index_keep)]
+                    other_true_indices = [i for i in true_index_list if i != true_index_keep]
+                    other_true_indices.sort(reverse=True)
+                    other_cluster_indices = [i for i in cluster_index_list if i != cluster_index_keep]
+                    other_cluster_indices.sort(reverse=True)
 
-                # Find indexes of colors
-                true_index_list = []  # Corresponds to the indices of the clusters in centers_array
-                cluster_index_list = []  # Corresponds to the indices of the clusters relative to labels_ and colors
-                for color in color_list:
-                    true_index_list.append(self.colors_.index(color))
-                    cluster_index_list.append(colors.index(color))
-                ips_list = list(self.ips_)
-                true_index_keep = ips_list.index(max(self.ips_[true_index_list]))
-                cluster_index_keep = cluster_index_list[true_index_list.index(true_index_keep)]
-                other_true_indices = [i for i in true_index_list if i != true_index_keep]
-                other_true_indices.sort(reverse=True)
-                other_cluster_indices = [i for i in cluster_index_list if i != cluster_index_keep]
-                other_cluster_indices.sort(reverse=True)
+                    # Adjust fit results accordingly
+                    self.n_comps_found_ -= len(other_true_indices)
+                    for i in other_true_indices:
+                        self.colors_.remove(self.colors_[i])
+                    for i in other_cluster_indices:
+                        self.labels_ = np.where(self.labels_ == i, cluster_index_keep, self.labels_)
+                    self.unique_labels_ = np.unique(self.labels_)
+                    labels_list = list(self.labels_)
+                    ips = []
+                    for n in self.unique_labels_:
+                        cluster_ions = labels_list.count(n)
+                        ips.append(cluster_ions)
+                    self.ips_ = np.array(ips)
 
-                # Adjust fit results accordingly
-                self.n_comps_found_ -= len(other_true_indices)
-                for i in other_true_indices:
-                    self.colors_.remove(self.colors_[i])
-                for i in other_cluster_indices:
-                    self.labels_ = np.where(self.labels_ == i, cluster_index_keep, self.labels_)
-                self.unique_labels_ = np.unique(self.labels_)
-                labels_list = list(self.labels_)
-                ips = []
-                for n in self.unique_labels_:
-                    cluster_ions = labels_list.count(n)
-                    ips.append(cluster_ions)
-                self.ips_ = np.array(ips)
+                    # Recalculate centers
+                    self.recalculate_centers_uncertainties(data_frame_object=data_frame_object)
 
-                # Recalculate centers
-                self.recalculate_centers_uncertainties(data_frame_object=data_frame_object)
-
-                if self.n_comps_found_ == 1:
-                    break
+                    if self.n_comps_found_ == 1:
+                        break
+                else:
+                    print("Please select at least 2 clusters. If there are no more merges you want "
+                          "to perform, enter 'n' when prompted.")
 
                 # Generate new figure
-                fig, save_string = self.show_results(data_frame_object=data_frame_object)
+                fig, save_string = self.get_results_fig(data_frame_object=data_frame_object)
 
                 # Prepare environment for GUI
                 canvas = FigureCanvas(fig)  # Initialize the canvas, which is the renderer that works with RGB values
@@ -472,7 +476,7 @@ class GaussianMixtureBase(metaclass=ABCMeta):
             else:
                 print("Invalid response. Please enter either 'y' or 'n'.")
 
-                fig, save_string = self.show_results(data_frame_object=data_frame_object)
+                fig, save_string = self.get_results_fig(data_frame_object=data_frame_object)
 
                 # Prepare environment for GUI
                 canvas = FigureCanvas(fig)  # Initialize the canvas, which is the renderer that works with RGB values
@@ -484,11 +488,11 @@ class GaussianMixtureBase(metaclass=ABCMeta):
 
                 color_list = []  # Initialize cluster list
 
-        fig, save_string = self.show_results(data_frame_object=data_frame_object)
+        fig, save_string = self.get_results_fig(data_frame_object=data_frame_object)
 
         return fig, save_string
 
-    def export_to_excel(self):
+    def export_to_clipboard(self):
         """Copies the centers, uncertainties, ips, and colors to
         an Excel format on the clipboard.
         """
