@@ -10,11 +10,13 @@
 import numpy as np
 import matplotlib.pyplot as plt
 import scipy.stats
-from ._base import GaussianMixtureBase
+
 from sklearn.mixture import BayesianGaussianMixture as BGM
+
 from ..sklearn_mixture_piicr import StrictBayesianGaussianMixture
 from ._data_frame import num_bins
 from ._data_frame import shift_phase_dimension
+from ._base import GaussianMixtureBase
 from ._gaussian_mixture_model import wt_avg_unc_number
 from ._gaussian_mixture_model import gauss_model_2save
 
@@ -23,7 +25,8 @@ class BayesianGaussianMixture(GaussianMixtureBase):
     """The class for implementing what we colloquially call the 'BGM' algorithms.
 
     Functionality includes: Cartesian or Polar Coordinates,
-    Spherical, Tied, Diagonal, or Full covariance matrices, and general or strict fits
+    Spherical, Tied, Diagonal, or Full covariance matrices,
+    and general or strict fits.
 
     version : 0.1
 
@@ -36,51 +39,39 @@ class BayesianGaussianMixture(GaussianMixtureBase):
 
 
     cov_type : {'full' (default), 'tied', 'diag', 'spherical'}
-        String describing the type of covariance parameters to use.
-        Must be one of:
-
-        'full'
-            each component has its own general covariance matrix
-        'tied'
-            all components share the same general covariance matrix
-        'diag'
-            each component has its own diagonal covariance matrix
-        'spherical'
-            each component has its own single variance
-
+        String describing the type of covariance parameters to use. Must be one of:
+            'full'
+                each component has its own general covariance matrix
+            'tied'
+                all components share the same general covariance matrix
+            'diag'
+                each component has its own diagonal covariance matrix
+            'spherical'
+                each component has its own single variance
         Taken from the sklearn package.
 
     tol : float, defaults to 1e-5
         The convergence threshold. EM iterations will stop when the
-        lower bound average gain is below this threshold.
-
-        Taken from the sklearn package.
+        lower bound average gain is below this threshold. Taken from
+        the sklearn package.
 
     max_iter : int, defaults to 500.
-        The number of EM iterations to perform.
-
-        Taken from the sklearn package.
+        The number of EM iterations to perform. Taken from the sklearn package.
 
     n_init : int, defaults to 30.
         The number of initializations to perform. The best results
-        are kept.
-
-        Taken from the sklearn package.
-
-    coordinates: {'Cartesian', 'Polar'}, defaults to 'Cartesian'
-        The coordinate system to work in.
-        Must be one of:
+        are kept. Taken from the sklearn package.
 
+    coordinates: {'Cartesian' (default), 'Polar'}
+        The coordinate system to work in. Must be one of:
             'Cartesian'
             'Polar'
 
     weight_concentration_prior_type : str, defaults to 'dirichlet_process'.
         String describing the type of the weight concentration prior.
-        Must be one of::
-
+        Must be one of:
             'dirichlet_process' (using the Stick-breaking representation),
             'dirichlet_distribution' (can favor more uniform weights).
-
         Taken directly from sklearn package.
 
     weight_concentration_prior : float | None, optional.
@@ -90,26 +81,20 @@ class BayesianGaussianMixture(GaussianMixtureBase):
         the center and will lead to more components being active, while a lower
         concentration parameter will lead to more mass at the edge of the
         mixture weights simplex. The value of the parameter must be greater
-        than 0. If it is None, it's set to ``1. / n_components``.
-
-        Taken directly from sklearn package.
+        than 0. If it is None, it's set to ``1. / n_components``. Taken directly
+        from sklearn package.
 
     Attributes
     ----------
     weights_ : array-like, shape (n_components,)
-        The weights of each mixture components.
-
-        Taken from the sklearn package.
+        The weights of each mixture components. Taken from the sklearn package.
 
     means_ : array-like, shape (n_components, n_features)
-        The mean of each mixture component.
-
-        Taken from the sklearn package.
+        The mean of each mixture component. Taken from the sklearn package.
 
     covariances_ : array-like
         The covariance of each mixture component.
-        The shape depends on `covariance_type`::
-
+        The shape depends on `covariance_type`:
             (n_components,)                        if 'spherical',
             (n_features, n_features)               if 'tied',
             (n_components, n_features)             if 'diag',
@@ -132,7 +117,7 @@ class BayesianGaussianMixture(GaussianMixtureBase):
     n_comps_found_ : int, defaults to n_components
         The number of components found by the fit.
         
-        centers_array_ : array-like, shape (n_components, 9)
+    centers_array_ : array-like, shape (n_components, 9)
         An array containing the centers of each component and 
         their uncertainties in each of the 4 coordinate dimensions,
         as well as the cluster uncertainty.
@@ -182,12 +167,14 @@ class BayesianGaussianMixture(GaussianMixtureBase):
         """Fit a Bayesian Gaussian Mixture to the data given by x.
 
         Parameters
+        ----------
         x : array-like, shape (n_samples, n_attributes)
             The data to be fit.
 
         Returns
         -------
         model : BayesianGaussianMixture from the sklearn package
+            The BayesianGaussianMixture object that has been fit to the data.
         """
         model = BGM(n_components=self.n_components, tol=self.tol,
                     max_iter=self.max_iter, n_init=self.n_init,
@@ -217,7 +204,8 @@ class BayesianGaussianMixture(GaussianMixtureBase):
 
         Returns
         -------
-        model : BayesianGaussianMixture from the sklearn package
+        model : StrictBayesianGaussianMixture from the sklearn package
+            The StrictBayesianGaussianMixture object that has been fit to the data.
         """
         model = StrictBayesianGaussianMixture(
             n_components=self.n_components, tol=self.tol,
@@ -233,10 +221,11 @@ class BayesianGaussianMixture(GaussianMixtureBase):
 
     def _calc_secondary_centers_unc(self, c1s, c1s_err, c2s,
                                     c2s_err, data_frame_object):
-        """Calculate the coordinates of the cluster centers for the coordinate system
-        that was not used for the fit.
+        """Calculate the coordinates of the cluster centers for the coordinate system that
+        was not used for the fit.
 
         Standard errors are calculated with typical standard error propagation methods.
+        Initialize the attribute 'centers_array_'.
 
         Parameters
         ----------
@@ -256,7 +245,7 @@ class BayesianGaussianMixture(GaussianMixtureBase):
         c2s_err : array-like, shape (n_components,)
             The standard error in the c2s.
 
-        data_frame_object : object from the class DataFrame
+        data_frame_object : DataFrame class object
             The object that contains the processed data and
             information that is used by the algorithms to do the
             fits.
@@ -265,6 +254,7 @@ class BayesianGaussianMixture(GaussianMixtureBase):
         xC_unc, yC_unc = data_frame_object.center_unc
 
         if self.coordinates == 'Cartesian':
+            # Calculate the radii and phases of cluster centers, with standard errors
             rs = np.sqrt(np.square(np.subtract(c1s, xC)) +
                          np.square(np.subtract(c2s, yC)))
             rs_err = np.sqrt(np.add(np.add(np.multiply(np.square(np.divide(
@@ -284,7 +274,7 @@ class BayesianGaussianMixture(GaussianMixtureBase):
                                                            np.subtract(c1s, xC))))),
                 np.divide(np.subtract(yC, c2s), np.square(np.subtract(c1s, xC)))),
                 c1s_err)), np.square(np.multiply(np.multiply(np.divide(1, np.add(
-                1, np.square(np.divide(np.subtract(c2s, yC), np.subtract(c1s, xC))))),
+                    1, np.square(np.divide(np.subtract(c2s, yC), np.subtract(c1s, xC))))),
                                                              np.divide(np.subtract(
                                                                  yC, c2s), np.square(
                                                                  np.subtract(c1s, xC)))), xC_unc))), np.add(
@@ -292,9 +282,9 @@ class BayesianGaussianMixture(GaussianMixtureBase):
                     np.divide(np.subtract(c2s, yC), np.subtract(c1s, xC))))),
                                                   np.divide(1, np.subtract(c1s, xC))),
                                       c2s_err)), np.square(np.multiply(np.multiply(
-                    np.divide(1, np.add(1, np.square(np.divide(np.subtract(c2s, yC),
-                                                               np.subtract(c1s, xC))))),
-                    np.divide(1, np.subtract(c1s, xC))), yC_unc))))))
+                                        np.divide(1, np.add(1, np.square(np.divide(np.subtract(c2s, yC),
+                                                            np.subtract(c1s, xC))))),
+                                        np.divide(1, np.subtract(c1s, xC))), yC_unc))))))
 
             cluster_err = np.sqrt(np.add(np.square(c1s_err),
                                          np.square(c2s_err)))
@@ -305,30 +295,37 @@ class BayesianGaussianMixture(GaussianMixtureBase):
                                              cluster_err)).T
 
         else:  # if self.coordinates == 'Polar':
+            # Calculate the x- and y- coordinates of the cluster centers, with standard errors.
+            # First, ensure data is not phase shifted.
             if data_frame_object.phase_shifted_:
                 shift = data_frame_object.phase_shift_
 
                 c2s += shift
                 c2s = np.where(c2s > 360, c2s - 360, c2s)
 
+                self.means_[:, 1] += shift
+                self.means_[:, 1] = np.where(
+                    self.means_[:, 1] > 360, self.means_[:, 1] - 360, self.means_[:, 1])
+
                 p_raw = data_frame_object.data_array_[:, 3]
                 p_raw += shift
                 p_raw = np.where(p_raw > 360, p_raw - 360, p_raw)
                 data_frame_object.data_array_[:, 3] = p_raw
                 data_frame_object.phase_shifted_ = False
 
+            # Convert to radians
             phases = np.deg2rad(c2s)
             phases_err = np.deg2rad(c2s_err)
 
             xs = np.add(np.multiply(c1s, np.cos(phases)), xC)
             xs_err = np.sqrt(np.add(np.add(np.square(np.multiply(np.cos(
                 phases), c1s_err)), np.square(np.multiply(
-                np.multiply(c1s, np.sin(phases)), phases_err))),
+                    np.multiply(c1s, np.sin(phases)), phases_err))),
                 xC_unc ** 2))
             ys = np.add(np.multiply(c1s, np.sin(phases)), yC)
             ys_err = np.sqrt(np.add(np.add(np.square(np.multiply(np.sin(
                 phases), c1s_err)), np.square(np.multiply(
-                np.multiply(c1s, np.cos(phases)), phases_err))),
+                    np.multiply(c1s, np.cos(phases)), phases_err))),
                 yC_unc ** 2))
             cluster_err = np.sqrt(np.add(np.square(xs_err),
                                          np.square(ys_err)))
@@ -345,7 +342,7 @@ class BayesianGaussianMixture(GaussianMixtureBase):
 
         Parameters
         ----------
-        data_frame_object : object from the class DataFrame
+        data_frame_object : DataFrame class object
             The object that contains the processed data and
             information that is used by the algorithms to do the
             fits.
@@ -399,21 +396,22 @@ class BayesianGaussianMixture(GaussianMixtureBase):
                   'aquamarine', 'cornflowerblue', 'saddlebrown',
                   'lightgray']
 
-        self.colors_ = colors[0:self.n_comps_found_]
+        self.colors_ = []
+        for i in self.unique_labels_:
+            self.colors_.append(colors[i])
 
     def recalculate_centers_uncertainties(self, data_frame_object):
         """Recalculate the centers of each cluster and the uncertainties in the centers.
 
         This uses a different method from simply extracting the centers
         and uncertainties from the fit. Instead, it fits a univariate Gaussian
-        curve to each dimension of each cluster and uses the
-        statistics from the fits to calculate the centers.
-
-        This method was written by Dwaipayan Ray and Adrian Valverde.
+        to each dimension of each cluster and uses the statistics from the
+        fits to calculate the centers. This method was written by Dwaipayan
+        Ray and Adrian Valverde.
 
         Parameters
         ----------
-        data_frame_object : object from the class DataFrame
+        data_frame_object : DataFrame class object
             The object that contains the processed data and
             information that is used by the algorithms to do the
             fits.
@@ -427,52 +425,16 @@ class BayesianGaussianMixture(GaussianMixtureBase):
 
         cp = data_frame_object.data_array_
 
-        c1_stuff, c2_stuff = {}, {}
-        # c1-s and c2-s of the spots in each cluster, with dictionary indexes as the cluster numbers
-        ions_psp_dict = {}  # ions per spot (psp), with dictionary indexes as the cluster numbers
-        rel_popu_psp_dict = {}
-        # relative population per spot (psp), with dictionary indexes as the cluster numbers
-        ions_psp = []  # ions per spot (psp)
-        rel_popu_psp = []  # relative population per spot (psp)
-
         cluster_ind = np.arange(0, self.n_comps_found_)  # array of cluster numbers
-        for i in cluster_ind:
-            if self.coordinates == 'Cartesian':
-                c1_stuff['%i' % i] = cp[self.labels_ ==
-                                        self.unique_labels_[i]][:, 0]
-                c2_stuff['%i' % i] = cp[self.labels_ ==
-                                        self.unique_labels_[i]][:, 1]
-            else:  # if self.coordinates == 'Polar':
-                c1_stuff['%i' % i] = cp[self.labels_ ==
-                                        self.unique_labels_[i]][:, 2]
-                c2_stuff['%i' % i] = cp[self.labels_ ==
-                                        self.unique_labels_[i]][:, 3]
-            '''
-            labels == i generates an array of just True (when 
-            labels values == i) and False (when labels values != i)
-            cp[labels == i] selects only those values from cp when 
-            the "labels==i" array has True value
-            cp[labels == i][:,0 or 1] selects the c1's or c2's from 
-            the cp[labels == i] array
-            '''
-            ions_psp_dict['%i' % i] = len(c1_stuff['%i' % i])
-            rel_popu_psp_dict['%i' % i] = 1.0 * len(
-                c1_stuff['%i' % i]) / len(cp[:, 0])
-
-            ions_psp.append(len(c1_stuff['%i' % i])) # ions per spot
-            rel_popu_psp.append(1.0 * len(c1_stuff['%i' % i]) /
-                                len(cp[:, 0]))
 
         c1s, c1s_err, c1_chi_sq, c1_red_chi_sq, c1_sigma_abs, \
-        c1_sigma_err, c1_height_abs, c1_height_err, c1_fw_hm_abs, \
-        c1_fw_hm_err = [], [], [], [], [], [], [], [], [], []
+            c1_sigma_err, c1_height_abs, c1_height_err, c1_fw_hm_abs, \
+            c1_fw_hm_err = [], [], [], [], [], [], [], [], [], []
         c2s, c2s_err, c2_chi_sq, c2_red_chi_sq, c2_sigma_abs, \
-        c2_sigma_err, c2_height_abs, c2_height_err, c2_fw_hm_abs, \
-        c2_fw_hm_err = [], [], [], [], [], [], [], [], [], []
+            c2_sigma_err, c2_height_abs, c2_height_err, c2_fw_hm_abs, \
+            c2_fw_hm_err = [], [], [], [], [], [], [], [], [], []
         cluster_err = []
 
-        c1_clusters, c2_clusters = {}, {}  # all c1's and c2's of the ion-hits in each cluster
-
         for i in cluster_ind:
             plt.figure()
             c1_cut = []
@@ -488,9 +450,6 @@ class BayesianGaussianMixture(GaussianMixtureBase):
                         c1_cut.append(cp[:, 2][j])
                         c2_cut.append(cp[:, 3][j])
 
-            c1_clusters['%i' % i] = c1_cut
-            c2_clusters['%i' % i] = c2_cut
-
             width_c1 = max(c1_cut) - min(c1_cut)
             width_c2 = max(c2_cut) - min(c2_cut)
 
@@ -591,17 +550,39 @@ class BayesianGaussianMixture(GaussianMixtureBase):
                         np.sqrt(c1_fit_array[1] ** 2 +
                                 c2_fit_array[1] ** 2))
 
-            plt.title('BGM c1_bins (cadetblue) = %i ; c2_bins '
+            plt.title('BGM %i comps c1_bins (cadetblue) = %i ; c2_bins '
                       '(orange) = %i\n(c1, c2) = (%0.2f,%0.2f),'
                       'Cluster unc=%0.5f' % (
-                          num_bins(c1_cut), num_bins(c2_cut), c1s[i], c2s[i],
-                          cluster_err[i]))
+                        self.n_comps_found_, num_bins(c1_cut),
+                        num_bins(c2_cut), c1s[i], c2s[i], cluster_err[i]))
             plt.xlim(-10, 10)
             plt.show()
 
         self._calc_secondary_centers_unc(c1s, c1s_err, c2s, c2s_err,
                                          data_frame_object)
 
+    def _cluster_data_one_d(self, x):
+        """Use the Bayesian Gaussian Mixture fit from the sklearn package to cluster the data.
+
+        Assigns the object the attributes 'means_',
+        'covariances_', 'weights_', 'labels_', 'responsibilities_',
+        and 'n_comps_found_'.
+
+        Parameters
+        ----------
+        x : array-like, shape (n_samples, n_attributes)
+            The data to be clustered.
+        """
+        model = self._BGM_fit(x)
+
+        # Assign attributes
+        self.means_ = model.means_
+        self.covariances_ = model.covariances_
+        self.weights_ = model.weights_
+        self.labels_ = model.predict(x)
+        self.responsibilities_ = model.predict_proba(x)
+        self.n_comps_found_ = np.shape(self.weights_)[0]
+
     def cluster_data(self, data_frame_object):
         """Use the Bayesian Gaussian Mixture from the sklearn package to cluster the data.
 
@@ -611,13 +592,14 @@ class BayesianGaussianMixture(GaussianMixtureBase):
 
         Parameters
         ----------
-        data_frame_object : object from the class DataFrame
+        data_frame_object : DataFrame class object
             The object that contains the processed data and
             information that is used by the algorithms to do the
             fits.
         """
         self._check_base_parameters()
 
+        # Gather data from data_frame_object
         if self.coordinates == 'Cartesian':
             data = data_frame_object.data_array_[
                    :, (0, 1)]
@@ -627,10 +609,10 @@ class BayesianGaussianMixture(GaussianMixtureBase):
             data = data_frame_object.data_array_[
                    :, (2, 3)]
 
-        model = self._BGM_fit(data)
+        model = self._BGM_fit(data)  # Fit model to data
 
+        # Assign attributes
         self.labels_ = model.predict(data)
-
         self.means_ = model.means_
         self.covariances_ = model.covariances_
         self.weights_ = model.weights_
@@ -649,13 +631,14 @@ class BayesianGaussianMixture(GaussianMixtureBase):
 
         Parameters
         ----------
-        data_frame_object : object from the class DataFrame
-                The object that contains the processed data and
-                information that is used by the algorithms to do the
-                fits.
+        data_frame_object : DataFrame class object
+            The object that contains the processed data and
+            information that is used by the algorithms to do the
+            fits.
         """
         self._check_base_parameters()
 
+        # Gather data from data_frame_object
         if self.coordinates == 'Cartesian':
             data = data_frame_object.data_array_[
                    :, (0, 1)]
@@ -667,6 +650,7 @@ class BayesianGaussianMixture(GaussianMixtureBase):
 
         model = self._strict_BGM_fit(data)
 
+        # Assign attributes
         self.means_ = model.means_
         self.covariances_ = model.covariances_
         self.weights_ = model.weights_
@@ -677,36 +661,15 @@ class BayesianGaussianMixture(GaussianMixtureBase):
 
         self._calculate_centers_uncertainties(data_frame_object)
 
-    def _cluster_data_one_d(self, x):
-        """Use the Bayesian Gaussian Mixture fit from the sklearn package to cluster the data.
-
-        Assigns the object the attributes 'means_',
-        'covariances_', 'weights_', 'labels_', 'responsibilities_',
-        and 'n_comps_found_'.
-
-        Parameters
-        ----------
-        x : array-like, shape (n_samples, n_attributes)
-            The data to be clustered
-        """
-        model = self._BGM_fit(x)
-
-        self.means_ = model.means_
-        self.covariances_ = model.covariances_
-        self.weights_ = model.weights_
-        self.labels_ = model.predict(x)
-        self.responsibilities_ = model.predict_proba(x)
-        self.n_comps_found_ = np.shape(self.weights_)[0]
-
     def fit_over_one_dimensional_histograms(self, fig, axs,
                                             data_frame_object):
         """Fit over the histograms generated with the data frame object.
 
         Given a data frame object that has already been used
         to generate histograms for each dimension of data, this
-        method will graph a GMM fit over each dimension. The
-        returned matplotlib.plyplot figure can be shown and saved
-        separately.
+        method will graph a GMM fit over each dimension. The returned
+        matplotlib.plyplot figure may be shown with the method plt.show()
+        or saved with the method plt.savefig() separately.
 
         Parameters
         ----------
@@ -716,7 +679,7 @@ class BayesianGaussianMixture(GaussianMixtureBase):
         axs : matplotlib.pyplot axes
             Contains the four different histograms.
 
-        data_frame_object : object from the class DataFrame
+        data_frame_object : DataFrame class object
             The object that contains the processed data and
             information that is used by the algorithms to do the
             fits.
@@ -763,7 +726,7 @@ class BayesianGaussianMixture(GaussianMixtureBase):
 
         return fig
 
-    def plot_pdf_surface(self, data_frame_object):
+    def get_pdf_fig(self, data_frame_object):
         """Plot the pdf of the Bayesian Gaussian mixture on a surface.
 
         The returned matplotlib.plyplot figure can be shown and saved
@@ -771,7 +734,7 @@ class BayesianGaussianMixture(GaussianMixtureBase):
 
         Parameters
         ----------
-        data_frame_object : object from the class DataFrame
+        data_frame_object : DataFrame class object
             The object that contains the processed data and
             information that is used by the algorithms to do the
             fits.
@@ -878,17 +841,17 @@ class BayesianGaussianMixture(GaussianMixtureBase):
 
         return fig, save_string
 
-    def show_results(self, data_frame_object):
+    def get_results_fig(self, data_frame_object):
         """Display the clustering results.
 
-        The returned matplotlib.plyplot figure can be shown and saved
-        separately.
-
-        This method was written by Dwaipayan Ray and Adrian Valverde.
+        The returned matplotlib.plyplot figure may be shown
+        with the method plt.show() or saved with the method
+        plt.savefig() separately. This method was written by
+        Dwaipayan Ray and Adrian Valverde.
 
         Parameters
         ----------
-        data_frame_object : object from the class DataFrame
+        data_frame_object : DataFrame class object
             The object that contains the processed data and
             information that is used by the algorithms to do the
             fits.
@@ -963,7 +926,7 @@ class BayesianGaussianMixture(GaussianMixtureBase):
                            fill=False, color='red'))
 
             plt.plot(data_array[my, 0], data_array[my, 1], 'o',
-                     color=col, markersize=2, label="%s:\n%s" % (
+                     color=col, markersize=3, label="%s:\n%s" % (
                     col, labels[index]))
 
         plt.errorbar(center_array[:, 0], center_array[:, 2],
