@@ -678,7 +678,7 @@ class PhaseFirstGaussianModel(GaussianMixtureBase):
 
         return fig
 
-    def plot_pdf_surface(self, data_frame_object):
+    def get_pdf_fig(self, data_frame_object):
         """Plot the pdf of the Gaussian mixture on a surface.
 
         The returned matplotlib.plyplot figure can be shown and saved
@@ -777,7 +777,7 @@ class PhaseFirstGaussianModel(GaussianMixtureBase):
 
         return fig, save_string
 
-    def show_results(self, data_frame_object):
+    def get_results_fig(self, data_frame_object):
         """Display the clustering results.
 
         The returned matplotlib.plyplot figure may be shown
@@ -859,7 +859,7 @@ class PhaseFirstGaussianModel(GaussianMixtureBase):
                            fill=False, color='red'))
 
             plt.plot(data_array[my, 0], data_array[my, 1], 'o',
-                     color=col, markersize=2, label="%s:\n%s" % (
+                     color=col, markersize=3, label="%s:\n%s" % (
                     col, labels[index]))
 
         plt.errorbar(center_array[:, 0], center_array[:, 2],
